Writing Quizzes for Quizdrill

The current version of this file is availible at our wiki-page.

# Quizdrill/Writing Quizzes

OpenFacts, the Open Source Knowledge Database

< Quizdrill

Our main quiz writer speaks German, so that version is getting more attention and a higher priority. It should be translated and extended here. Help is always welcome.

Please don't hesitate to ask on the mailing list.

## Converting quiz files from other programs

### langdrill

langdrill drill files are very similar to quizdrill's. The only difference are the header lines. To convert a langdrill drill file, replace the [Application]-section with

!type: vocabulary
!language: <value of "directSenseName">=<value of "reverseSenseName">

and that is it. Note however, that quizdrill has a style-guideline for the quizfiles, which you might want to follow. However this can be done quickly and is not mandatory to be included to the quizdrill quizzes. So just send then to us rather than waiting into you are in the mood to fix it yourself ;-).